@@ -534,6 +534,7 @@ private:
     QHash<int, NoteHistoryItem> _activeNoteFolderNotePositions;
     bool _searchLineEditFromCompleter;
     bool _isNotesDirectoryWasModifiedDisabled;
+    bool _isNotesWereModifiedDisabled;
     bool _isDefaultShortcutInitialized;
     QList<QShortcut *> _menuShortcuts;
     bool _showNotesFromAllNoteSubFolders;
@@ -838,4 +839,20 @@ private:
     void updateNotesPanelSortOrder();
 
     void selectAllNotesInTagTreeWidget() const;
+
+    void handleScriptingNoteTagging(Note note, QString tagName,
+                                    bool doRemove = false,
+                                    bool triggerPostMethods = true);
+
+    void handleScriptingRemoveNoteTag(Note note, QString tagName);
+
+    void handleScriptingNotesTagUpdating();
+
+    void handleScriptingNotesTagRenaming(QString oldTagName, QString newTagName);
+
+    void handleScriptingNotesTagRemoving(QString tagName,
+                                         bool forBulkOperation = false);
+
+    void directoryWatcherWorkaround(bool isNotesDirectoryWasModifiedDisabled,
+                                    bool alsoHandleNotesWereModified = false);
 };
